import numpy as np
import h5py
import matplotlib.pyplot as plt
import matplotlib.cm as cm

# set name of file and observation mode
filename='GPMCOR_DPR_1512282046_2218_010412_L2S_DD2_06A.h5'
mode='MS'

with h5py.File(filename,"r") as infile:
    #convert data to numpy ndarray
    Lat=np.array(infile[mode+'/Latitude']).T
    Lon=np.array(infile[mode+'/Longitude']).T
    Lon=np.unwrap(Lon)
    precipRateESurf=np.array(infile[mode+'/SLV/precipRateESurface']).T
    ZeESurf=np.array(infile[mode+'/SLV/zFactorCorrectedESurface']).T
    # see file specification guide about the directories and parameters
    Nscan=Lon.shape[0]  # total number of scan
    Nray=Lon.shape[1]   # number of FOV(number of angle)

# python2
#print 'Estimated Surfase Rain at %f,%f: %f'% (Lon[9][7093],Lat[9][7093],precipRateESurf[9][7093]) # precepRateESurface at Scan=7093,FOV=9
#print 'Number of Rainy c:ells/all: %d/%d'% (len(np.where(precipRateESurf>0)[0]), precipRateESurf.size) 

# python3
print('Estimated Surfase Rain at {0},{1}: {2}'.format(Lon[9][7093],Lat[9][7093],precipRateESurf[9][7093]))
print('Number of Rainy cells/all: {0}/{1}'.format(len(np.where(precipRateESurf>0)[0]), precipRateESurf.size))

#slicing data. new array contains data of Scan 7000 to 7200 
lon=Lon[:, 7000:7200]
lat=Lat[:, 7000:7200]
rr=precipRateESurf[:, 7000:7200]

# calculate statistics of numpy ndarray (for example)
Mean=rr.mean() 
STD=rr.std() 

#plot with Matplotlib
plt.plot(Lon[9][7093],Lat[9][7093],"+", c='white')
plt.pcolormesh(lon,lat,rr) 
plt.show()
plt.close()
